<a id="types-aiobotocore-docdb"></a>

# types-aiobotocore-docdb

[![PyPI - types-aiobotocore-docdb](https://img.shields.io/pypi/v/types-aiobotocore-docdb.svg?color=blue)](https://pypi.org/project/types-aiobotocore-docdb)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-aiobotocore-docdb.svg?color=blue)](https://pypi.org/project/types-aiobotocore-docdb)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/types-aiobotocore-docdb?color=blue)](https://pypistats.org/packages/types-aiobotocore-docdb)

![boto3.typed](https://github.com/youtype/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[aiobotocore.DocDB 2.5.0](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/docdb.html#DocDB)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 7.12.5](https://github.com/youtype/mypy_boto3_builder).

More information can be found on
[types-aiobotocore](https://pypi.org/project/types-aiobotocore/) page and in
[types-aiobotocore-docdb docs](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_docdb/).

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/youtype/mypy_boto3_builder/raw/main/demo.gif)

- [types-aiobotocore-docdb](#types-aiobotocore-docdb)
  - [How to install](#how-to-install)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [How to uninstall](#how-to-uninstall)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Emacs](#emacs)
    - [Sublime Text](#sublime-text)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [How it works](#how-it-works)
  - [What's new](#what's-new)
    - [Implemented features](#implemented-features)
    - [Latest changes](#latest-changes)
  - [Versioning](#versioning)
  - [Thank you](#thank-you)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `types-aiobotocore` for `DocDB` service.

```bash
# install with aiobotocore type annotations
python -m pip install 'types-aiobotocore[docdb]'


# Lite version does not provide session.client/resource overloads
# it is more RAM-friendly, but requires explicit type annotations
python -m pip install 'types-aiobotocore-lite[docdb]'


# standalone installation
python -m pip install types-aiobotocore-docdb
```

<a id="how-to-uninstall"></a>

## How to uninstall

```bash
python -m pip uninstall -y types-aiobotocore-docdb
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `types-aiobotocore[docdb]` in your environment:

```bash
python -m pip install 'types-aiobotocore[docdb]'
```

Both type checking and code completion should now work. No explicit type
annotations required, write your `aiobotocore` code as usual.

<a id="pycharm"></a>

### PyCharm

Install `types-aiobotocore-lite[docdb]` in your environment:

```bash
python -m pip install 'types-aiobotocore-lite[docdb]'`
```

Both type checking and code completion should now work. Explicit type
annotations **are required**.

Use `types-aiobotocore` package instead for implicit type discovery.

<a id="emacs"></a>

### Emacs

- Install `types-aiobotocore` with services you use in your environment:

```bash
python -m pip install 'types-aiobotocore[docdb]'
```

- Install [use-package](https://github.com/jwiegley/use-package),
  [lsp](https://github.com/emacs-lsp/lsp-mode/),
  [company](https://github.com/company-mode/company-mode) and
  [flycheck](https://github.com/flycheck/flycheck) packages
- Install [lsp-pyright](https://github.com/emacs-lsp/lsp-pyright) package

```elisp
(use-package lsp-pyright
  :ensure t
  :hook (python-mode . (lambda ()
                          (require 'lsp-pyright)
                          (lsp)))  ; or lsp-deferred
  :init (when (executable-find "python3")
          (setq lsp-pyright-python-executable-cmd "python3"))
  )
```

- Make sure emacs uses the environment where you have installed
  `types-aiobotocore`

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="sublime-text"></a>

### Sublime Text

- Install `types-aiobotocore[docdb]` with services you use in your environment:

```bash
python -m pip install 'types-aiobotocore[docdb]'
```

- Install [LSP-pyright](https://github.com/sublimelsp/LSP-pyright) package

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `types-aiobotocore[docdb]` in your environment:

```bash
python -m pip install 'types-aiobotocore[docdb]'`
```

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `npm i -g pyright`
- Install `types-aiobotocore[docdb]` in your environment:

```bash
python -m pip install 'types-aiobotocore[docdb]'
```

Optionally, you can install `types-aiobotocore` to `typings` folder.

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`DocDBClient` provides annotations for `session.create_client("docdb")`.

```python
from aiobotocore.session import get_session

from types_aiobotocore_docdb import DocDBClient

session = get_session()
async with session.create_client("docdb") as client:
    client: DocDBClient
    # now client usage is checked by mypy and IDE should provide code completion
```

<a id="paginators-annotations"></a>

### Paginators annotations

`types_aiobotocore_docdb.paginator` module contains type annotations for all
paginators.

```python
from aiobotocore.session import get_session

from types_aiobotocore_docdb import DocDBClient
from types_aiobotocore_docdb.paginator import (
    DescribeCertificatesPaginator,
    DescribeDBClusterParameterGroupsPaginator,
    DescribeDBClusterParametersPaginator,
    DescribeDBClusterSnapshotsPaginator,
    DescribeDBClustersPaginator,
    DescribeDBEngineVersionsPaginator,
    DescribeDBInstancesPaginator,
    DescribeDBSubnetGroupsPaginator,
    DescribeEventSubscriptionsPaginator,
    DescribeEventsPaginator,
    DescribeGlobalClustersPaginator,
    DescribeOrderableDBInstanceOptionsPaginator,
    DescribePendingMaintenanceActionsPaginator,
)

session = get_session()
async with session.create_client("docdb") as client:
    client: DocDBClient

    # Explicit type annotations are optional here
    # Types should be correctly discovered by mypy and IDEs
    describe_certificates_paginator: DescribeCertificatesPaginator = client.get_paginator(
        "describe_certificates"
    )
    describe_db_cluster_parameter_groups_paginator: DescribeDBClusterParameterGroupsPaginator = (
        client.get_paginator("describe_db_cluster_parameter_groups")
    )
    describe_db_cluster_parameters_paginator: DescribeDBClusterParametersPaginator = (
        client.get_paginator("describe_db_cluster_parameters")
    )
    describe_db_cluster_snapshots_paginator: DescribeDBClusterSnapshotsPaginator = (
        client.get_paginator("describe_db_cluster_snapshots")
    )
    describe_db_clusters_paginator: DescribeDBClustersPaginator = client.get_paginator(
        "describe_db_clusters"
    )
    describe_db_engine_versions_paginator: DescribeDBEngineVersionsPaginator = client.get_paginator(
        "describe_db_engine_versions"
    )
    describe_db_instances_paginator: DescribeDBInstancesPaginator = client.get_paginator(
        "describe_db_instances"
    )
    describe_db_subnet_groups_paginator: DescribeDBSubnetGroupsPaginator = client.get_paginator(
        "describe_db_subnet_groups"
    )
    describe_event_subscriptions_paginator: DescribeEventSubscriptionsPaginator = (
        client.get_paginator("describe_event_subscriptions")
    )
    describe_events_paginator: DescribeEventsPaginator = client.get_paginator("describe_events")
    describe_global_clusters_paginator: DescribeGlobalClustersPaginator = client.get_paginator(
        "describe_global_clusters"
    )
    describe_orderable_db_instance_options_paginator: DescribeOrderableDBInstanceOptionsPaginator = client.get_paginator(
        "describe_orderable_db_instance_options"
    )
    describe_pending_maintenance_actions_paginator: DescribePendingMaintenanceActionsPaginator = (
        client.get_paginator("describe_pending_maintenance_actions")
    )
```

<a id="waiters-annotations"></a>

### Waiters annotations

`types_aiobotocore_docdb.waiter` module contains type annotations for all
waiters.

```python
from aiobotocore.session import get_session

from types_aiobotocore_docdb.client import DocDBClient
from types_aiobotocore_docdb.waiter import DBInstanceAvailableWaiter, DBInstanceDeletedWaiter

session = get_session()
async with session.create_client("docdb") as client:
    client: DocDBClient

    # Explicit type annotations are optional here
    # Types should be correctly discovered by mypy and IDEs
    db_instance_available_waiter: DBInstanceAvailableWaiter = client.get_waiter(
        "db_instance_available"
    )
    db_instance_deleted_waiter: DBInstanceDeletedWaiter = client.get_waiter("db_instance_deleted")
```

<a id="literals"></a>

### Literals

`types_aiobotocore_docdb.literals` module contains literals extracted from
shapes that can be used in user code for type checking.

```python
from types_aiobotocore_docdb.literals import (
    ApplyMethodType,
    DBInstanceAvailableWaiterName,
    DBInstanceDeletedWaiterName,
    DescribeCertificatesPaginatorName,
    DescribeDBClusterParameterGroupsPaginatorName,
    DescribeDBClusterParametersPaginatorName,
    DescribeDBClusterSnapshotsPaginatorName,
    DescribeDBClustersPaginatorName,
    DescribeDBEngineVersionsPaginatorName,
    DescribeDBInstancesPaginatorName,
    DescribeDBSubnetGroupsPaginatorName,
    DescribeEventSubscriptionsPaginatorName,
    DescribeEventsPaginatorName,
    DescribeGlobalClustersPaginatorName,
    DescribeOrderableDBInstanceOptionsPaginatorName,
    DescribePendingMaintenanceActionsPaginatorName,
    SourceTypeType,
    DocDBServiceName,
    ServiceName,
    ResourceServiceName,
    PaginatorName,
    WaiterName,
    RegionName,
)


def check_value(value: ApplyMethodType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`types_aiobotocore_docdb.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from types_aiobotocore_docdb.type_defs import (
    AddSourceIdentifierToSubscriptionMessageRequestTypeDef,
    EventSubscriptionTypeDef,
    ResponseMetadataTypeDef,
    TagTypeDef,
    ApplyPendingMaintenanceActionMessageRequestTypeDef,
    AvailabilityZoneTypeDef,
    CertificateTypeDef,
    CloudwatchLogsExportConfigurationTypeDef,
    DBClusterParameterGroupTypeDef,
    DBClusterSnapshotTypeDef,
    CreateGlobalClusterMessageRequestTypeDef,
    DBClusterMemberTypeDef,
    ParameterTypeDef,
    DBClusterRoleTypeDef,
    DBClusterSnapshotAttributeTypeDef,
    VpcSecurityGroupMembershipTypeDef,
    UpgradeTargetTypeDef,
    DBInstanceStatusInfoTypeDef,
    EndpointTypeDef,
    DeleteDBClusterMessageRequestTypeDef,
    DeleteDBClusterParameterGroupMessageRequestTypeDef,
    DeleteDBClusterSnapshotMessageRequestTypeDef,
    DeleteDBInstanceMessageRequestTypeDef,
    DeleteDBSubnetGroupMessageRequestTypeDef,
    DeleteEventSubscriptionMessageRequestTypeDef,
    DeleteGlobalClusterMessageRequestTypeDef,
    FilterTypeDef,
    PaginatorConfigTypeDef,
    DescribeDBClusterSnapshotAttributesMessageRequestTypeDef,
    WaiterConfigTypeDef,
    EventCategoriesMapTypeDef,
    EventTypeDef,
    FailoverDBClusterMessageRequestTypeDef,
    GlobalClusterMemberTypeDef,
    ModifyDBClusterSnapshotAttributeMessageRequestTypeDef,
    ModifyDBInstanceMessageRequestTypeDef,
    ModifyDBSubnetGroupMessageRequestTypeDef,
    ModifyEventSubscriptionMessageRequestTypeDef,
    ModifyGlobalClusterMessageRequestTypeDef,
    PendingCloudwatchLogsExportsTypeDef,
    PendingMaintenanceActionTypeDef,
    RebootDBInstanceMessageRequestTypeDef,
    RemoveFromGlobalClusterMessageRequestTypeDef,
    RemoveSourceIdentifierFromSubscriptionMessageRequestTypeDef,
    RemoveTagsFromResourceMessageRequestTypeDef,
    StartDBClusterMessageRequestTypeDef,
    StopDBClusterMessageRequestTypeDef,
    AddSourceIdentifierToSubscriptionResultTypeDef,
    CreateEventSubscriptionResultTypeDef,
    DBClusterParameterGroupNameMessageTypeDef,
    DeleteEventSubscriptionResultTypeDef,
    EmptyResponseMetadataTypeDef,
    EventSubscriptionsMessageTypeDef,
    ModifyEventSubscriptionResultTypeDef,
    RemoveSourceIdentifierFromSubscriptionResultTypeDef,
    AddTagsToResourceMessageRequestTypeDef,
    CopyDBClusterParameterGroupMessageRequestTypeDef,
    CopyDBClusterSnapshotMessageRequestTypeDef,
    CreateDBClusterMessageRequestTypeDef,
    CreateDBClusterParameterGroupMessageRequestTypeDef,
    CreateDBClusterSnapshotMessageRequestTypeDef,
    CreateDBInstanceMessageRequestTypeDef,
    CreateDBSubnetGroupMessageRequestTypeDef,
    CreateEventSubscriptionMessageRequestTypeDef,
    RestoreDBClusterFromSnapshotMessageRequestTypeDef,
    RestoreDBClusterToPointInTimeMessageRequestTypeDef,
    TagListMessageTypeDef,
    OrderableDBInstanceOptionTypeDef,
    SubnetTypeDef,
    CertificateMessageTypeDef,
    ModifyDBClusterMessageRequestTypeDef,
    CopyDBClusterParameterGroupResultTypeDef,
    CreateDBClusterParameterGroupResultTypeDef,
    DBClusterParameterGroupsMessageTypeDef,
    CopyDBClusterSnapshotResultTypeDef,
    CreateDBClusterSnapshotResultTypeDef,
    DBClusterSnapshotMessageTypeDef,
    DeleteDBClusterSnapshotResultTypeDef,
    DBClusterParameterGroupDetailsTypeDef,
    EngineDefaultsTypeDef,
    ModifyDBClusterParameterGroupMessageRequestTypeDef,
    ResetDBClusterParameterGroupMessageRequestTypeDef,
    DBClusterSnapshotAttributesResultTypeDef,
    DBClusterTypeDef,
    DBEngineVersionTypeDef,
    DescribeCertificatesMessageRequestTypeDef,
    DescribeDBClusterParameterGroupsMessageRequestTypeDef,
    DescribeDBClusterParametersMessageRequestTypeDef,
    DescribeDBClusterSnapshotsMessageRequestTypeDef,
    DescribeDBClustersMessageRequestTypeDef,
    DescribeDBEngineVersionsMessageRequestTypeDef,
    DescribeDBInstancesMessageRequestTypeDef,
    DescribeDBSubnetGroupsMessageRequestTypeDef,
    DescribeEngineDefaultClusterParametersMessageRequestTypeDef,
    DescribeEventCategoriesMessageRequestTypeDef,
    DescribeEventSubscriptionsMessageRequestTypeDef,
    DescribeEventsMessageRequestTypeDef,
    DescribeGlobalClustersMessageRequestTypeDef,
    DescribeOrderableDBInstanceOptionsMessageRequestTypeDef,
    DescribePendingMaintenanceActionsMessageRequestTypeDef,
    ListTagsForResourceMessageRequestTypeDef,
    DescribeCertificatesMessageDescribeCertificatesPaginateTypeDef,
    DescribeDBClusterParameterGroupsMessageDescribeDBClusterParameterGroupsPaginateTypeDef,
    DescribeDBClusterParametersMessageDescribeDBClusterParametersPaginateTypeDef,
    DescribeDBClusterSnapshotsMessageDescribeDBClusterSnapshotsPaginateTypeDef,
    DescribeDBClustersMessageDescribeDBClustersPaginateTypeDef,
    DescribeDBEngineVersionsMessageDescribeDBEngineVersionsPaginateTypeDef,
    DescribeDBInstancesMessageDescribeDBInstancesPaginateTypeDef,
    DescribeDBSubnetGroupsMessageDescribeDBSubnetGroupsPaginateTypeDef,
    DescribeEventSubscriptionsMessageDescribeEventSubscriptionsPaginateTypeDef,
    DescribeEventsMessageDescribeEventsPaginateTypeDef,
    DescribeGlobalClustersMessageDescribeGlobalClustersPaginateTypeDef,
    DescribeOrderableDBInstanceOptionsMessageDescribeOrderableDBInstanceOptionsPaginateTypeDef,
    DescribePendingMaintenanceActionsMessageDescribePendingMaintenanceActionsPaginateTypeDef,
    DescribeDBInstancesMessageDBInstanceAvailableWaitTypeDef,
    DescribeDBInstancesMessageDBInstanceDeletedWaitTypeDef,
    EventCategoriesMessageTypeDef,
    EventsMessageTypeDef,
    GlobalClusterTypeDef,
    PendingModifiedValuesTypeDef,
    ResourcePendingMaintenanceActionsTypeDef,
    OrderableDBInstanceOptionsMessageTypeDef,
    DBSubnetGroupTypeDef,
    DescribeEngineDefaultClusterParametersResultTypeDef,
    DescribeDBClusterSnapshotAttributesResultTypeDef,
    ModifyDBClusterSnapshotAttributeResultTypeDef,
    CreateDBClusterResultTypeDef,
    DBClusterMessageTypeDef,
    DeleteDBClusterResultTypeDef,
    FailoverDBClusterResultTypeDef,
    ModifyDBClusterResultTypeDef,
    RestoreDBClusterFromSnapshotResultTypeDef,
    RestoreDBClusterToPointInTimeResultTypeDef,
    StartDBClusterResultTypeDef,
    StopDBClusterResultTypeDef,
    DBEngineVersionMessageTypeDef,
    CreateGlobalClusterResultTypeDef,
    DeleteGlobalClusterResultTypeDef,
    GlobalClustersMessageTypeDef,
    ModifyGlobalClusterResultTypeDef,
    RemoveFromGlobalClusterResultTypeDef,
    ApplyPendingMaintenanceActionResultTypeDef,
    PendingMaintenanceActionsMessageTypeDef,
    CreateDBSubnetGroupResultTypeDef,
    DBInstanceTypeDef,
    DBSubnetGroupMessageTypeDef,
    ModifyDBSubnetGroupResultTypeDef,
    CreateDBInstanceResultTypeDef,
    DBInstanceMessageTypeDef,
    DeleteDBInstanceResultTypeDef,
    ModifyDBInstanceResultTypeDef,
    RebootDBInstanceResultTypeDef,
)


def get_structure() -> AddSourceIdentifierToSubscriptionMessageRequestTypeDef:
    return {...}
```

<a id="how-it-works"></a>

## How it works

Fully automated
[mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder) carefully
generates type annotations for each service, patiently waiting for
`aiobotocore` updates. It delivers a drop-in type annotations for you and makes
sure that:

- All available `aiobotocore` services are covered.
- Each public class and method of every `aiobotocore` service gets valid type
  annotations extracted from the documentation (blame `botocore` docs if types
  are incorrect).
- Type annotations include up-to-date documentation.
- Link to documentation is provided for every method.
- Code is processed by [black](https://github.com/psf/black) and
  [isort](https://github.com/PyCQA/isort) for readability.

<a id="what's-new"></a>

## What's new

<a id="implemented-features"></a>

### Implemented features

- Fully type annotated `boto3`, `botocore` and `aiobotocore` libraries
- `mypy`, `pyright`, `VSCode`, `PyCharm`, `Sublime Text` and `Emacs`
  compatibility
- `Client`, `ServiceResource`, `Resource`, `Waiter` `Paginator` type
  annotations for each service
- Generated `TypeDefs` for each service
- Generated `Literals` for each service
- Auto discovery of types for `boto3.client` and `boto3.session` calls
- Auto discovery of types for `session.client` and `session.session` calls
- Auto discovery of types for `client.get_waiter` and `client.get_paginator`
  calls
- Auto discovery of types for `ServiceResource` and `Resource` collections
- Auto discovery of types for `aiobotocore.Session.create_client` calls

<a id="latest-changes"></a>

### Latest changes

Builder changelog can be found in
[Releases](https://github.com/youtype/mypy_boto3_builder/releases).

<a id="versioning"></a>

## Versioning

`types-aiobotocore-docdb` version is the same as related `aiobotocore` version
and follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="thank-you"></a>

## Thank you

- [Allie Fitter](https://github.com/alliefitter) for
  [boto3-type-annotations](https://pypi.org/project/boto3-type-annotations/),
  this package is based on top of his work
- [black](https://github.com/psf/black) developers for an awesome formatting
  tool
- [Timothy Edmund Crosley](https://github.com/timothycrosley) for
  [isort](https://github.com/PyCQA/isort) and how flexible it is
- [mypy](https://github.com/python/mypy) developers for doing all dirty work
  for us
- [pyright](https://github.com/microsoft/pyright) team for the new era of typed
  Python

<a id="documentation"></a>

## Documentation

All services type annotations can be found in
[aiobotocore docs](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_docdb/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder/issues/)
repository.
